"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const settings = {
    doNotUseSamePrefix: false,
    doNotCreateSameFluxType: false,
    logPrefix: false,
    logFluxType: false,
    addIdToSuffix: false,
};
const cachedPrefixList = [];
const cachedFluxTypeList = [];
let _id = 0;
function setting(config) {
    Object.assign(settings, config);
}
exports.setting = setting;
function actionCreatorFactory(prefix) {
    if (prefix && settings.doNotUseSamePrefix) {
        if (cachedPrefixList.includes(prefix)) {
            throw Error(`Prefix [${prefix}] is already used.`);
        }
        cachedPrefixList.push(prefix);
    }
    if (settings.logPrefix) {
        console.log(`Success to used prefix! That is [${prefix}].`);
    }
    return (type) => {
        let base = prefix ? `${prefix}/${type}` : type;
        if (settings.addIdToSuffix) {
            _id++;
            base = `${base}__${_id}`;
        }
        if (settings.doNotCreateSameFluxType) {
            if (cachedFluxTypeList.includes(base)) {
                throw Error(`FluxType [${base}] is already used.`);
            }
            cachedFluxTypeList.push(base);
        }
        if (settings.logFluxType) {
            console.log(`Success to used FluxType! That is [${base}].`);
        }
        return Object.assign((payload, options) => {
            return {
                type: options && options.namespace ? `${options.namespace}/${base}` : base,
                payload,
                error: options && options.error,
                meta: options && options.meta,
            };
        }, {
            type: base,
        });
    };
}
exports.actionCreatorFactory = actionCreatorFactory;
